/*
** Module   : WebSocketServlet.java
** Abstract : A WebSocket used for tests.
**
** Copyright (c) 2009-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131105 First version based on jetty 9.1
*/

package com.goldencode.p2j.ws.test;

import java.io.*;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.eclipse.jetty.websocket.api.*;
import org.eclipse.jetty.websocket.api.annotations.*;

import com.goldencode.p2j.util.*;

/**
 * A simple POJO WebSocket class. 
 * <p>
 * Methods to create WebSockets:
 * <ul>
 *    <li>POJO WebSocket using annotations.</li>
 *    <li>Implements WebSocketListener interface.</li>
 *    <li>Extends WebSocketAdapter class.</li>
 * </ul>
 */
@WebSocket
public class WebSocketServlet
{
   /** Logger. */
   private static final Logger LOG = 
            LogHelper.getLogger(WebSocketServlet.class.getName());
   
   /**  Object representing the other end of this conversation. */
   private RemoteEndpoint remote;

   @OnWebSocketConnect
   public void onConnect(Session session)
   {
      LOG.info("WebSocket Opened");
      this.remote = session.getRemote();
   }

   @OnWebSocketMessage
   public void onMessage(String message)
   {
      LOG.warning("Message from Client: " + message);
      try
      {
         remote.sendString("Hi Client");
      }
      catch (IOException e)
      {
         LOG.logp(Level.SEVERE,
                  "WebSocketServlet.onMessage()",
                  "",
                  LogHelper.generate("IOException!"),
                  e);         
      }
   }

   @OnWebSocketClose
   public void onClose(int statusCode, String reason)
   {
      LOG.info("WebSocket Closed. Code:" + statusCode);
   }

   @OnWebSocketError
   public void onError(Session session, Throwable error)
   {
      LOG.logp(Level.SEVERE,
               "WebSocketServlet.onError()",
               "",
               LogHelper.generate("Error!"),
               error);       
   }

}